
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.28.1',
    'branch_nick': 'release-1.28',
    'revision_id': 'bc821e4abc6d54fd86de9101511f95cdb5455761',
    'revno': 11505
}
